==> goldsmith-jewelry-store-woocommerce-theme-1.3.9%28www.persianscript.ir%29.zip: goldsmith-elementor-addons/classes/class-custom-kit-settings.php <==
<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Kit;
use Elementor\Core\Kits\Documents\Tabs\Tab_Base;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
* Class Theme_Style_Kits
*
* @package Analog\Elementor\Kit\Tabs
*/
class Themee_Style_Kits extends Tab_Base {

    /**
    * Tab ID.
    *
    * @return string
    */
    public function get_id() {
        return 'themee-style-kits';
    }

    /**
    * Tab title.
    *
    * @return string|void
    */
    public function get_title() {
        return __( 'Goldsmith Style Kits', 'ang' );
    }

    /**
    * Tab Group.
    *
    * @return string
    */
    public function get_group() {
        return 'goldsmith-style';
    }

    /**
    * Tab icon.
    *
    * @return string
    */
    public function get_icon() {
        return 'eicon-global-settings';
    }

    /**
    * Tab help URL.
    *
    * @return string
    */
    public function get_help_url() {
        return 'https://docs.analogwp.com/';
    }

    /**
    * Tab controls.
    *
    * Tab controls are hooked mostly on `elementor/element/kit/section_buttons/after_section_end`.
    */
    protected function register_tab_controls() {

        $this->start_controls_section(
            'vsection_' . $this->get_id(),
            [
                'label' => $this->get_title(),
                'tab' => $this->get_id(),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_default_padding',
            [
                'label' => esc_html__( 'Default Column Padding', 'goldsmith' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-default-padding',
                'variable'  => 'goldsmith_column_default_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_default_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_wide_padding',
            [
                'label' => esc_html__( 'Wide Column Padding', 'goldsmith' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-wide-padding',
                'variable'  => 'goldsmith_column_wide_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_wide_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_wider_padding',
            [
                'label' => esc_html__( 'Wider Column Padding', 'goldsmith' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-wider-padding',
                'variable'  => 'goldsmith_column_wider_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_wider_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_extended_padding',
            [
                'label' => esc_html__( 'Extended Column Padding', 'goldsmith' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'variable'  => 'goldsmith_column_extended_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_extended_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->end_controls_section();
    }
}

new Themee_Style_Kits( Kit::class );

/**
* Fires on tabs registering.
*/
add_action(
    'elementor/kit/register_tabs',
    function( $kit ) {
        $kit->register_tab( 'themee-style-kits', Themee_Style_Kits::class );
    }
);

==> goldsmith-jewelry-store-woocommerce-theme-1.4.3%28www.persianscript.ir%29.zip: goldsmith-elementor-addons/classes/class-custom-kit-settings.php <==
<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Kit;
use Elementor\Core\Kits\Documents\Tabs\Tab_Base;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
* Class Theme_Style_Kits
*
* @package Analog\Elementor\Kit\Tabs
*/
class Themee_Style_Kits extends Tab_Base {

    /**
    * Tab ID.
    *
    * @return string
    */
    public function get_id() {
        return 'themee-style-kits';
    }

    /**
    * Tab title.
    *
    * @return string|void
    */
    public function get_title() {
        return __( 'Goldsmith Style Kits', 'ang' );
    }

    /**
    * Tab Group.
    *
    * @return string
    */
    public function get_group() {
        return 'goldsmith-style';
    }

    /**
    * Tab icon.
    *
    * @return string
    */
    public function get_icon() {
        return 'eicon-global-settings';
    }

    /**
    * Tab help URL.
    *
    * @return string
    */
    public function get_help_url() {
        return 'https://docs.analogwp.com/';
    }

    /**
    * Tab controls.
    *
    * Tab controls are hooked mostly on `elementor/element/kit/section_buttons/after_section_end`.
    */
    protected function register_tab_controls() {

        $this->start_controls_section(
            'vsection_' . $this->get_id(),
            [
                'label' => $this->get_title(),
                'tab' => $this->get_id(),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_default_padding',
            [
                'label' => esc_html__( 'Default Column Padding', 'goldsmith-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-default-padding',
                'variable'  => 'goldsmith_column_default_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_default_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_wide_padding',
            [
                'label' => esc_html__( 'Wide Column Padding', 'goldsmith-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-wide-padding',
                'variable'  => 'goldsmith_column_wide_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_wide_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_wider_padding',
            [
                'label' => esc_html__( 'Wider Column Padding', 'goldsmith-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'prefix_class' => 'goldsmith-column-wider-padding',
                'variable'  => 'goldsmith_column_wider_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_wider_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->add_responsive_control(
            'goldsmith_column_extended_padding',
            [
                'label' => esc_html__( 'Extended Column Padding', 'goldsmith-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'frontend_available' => true,
                'variable'  => 'goldsmith_column_extended_padding',
                'selectors' => array(
                    '{{WRAPPER}}' => '--goldsmith_column_extended_padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ),
            ]
        );
        $this->end_controls_section();
    }
}

new Themee_Style_Kits( Kit::class );

/**
* Fires on tabs registering.
*/
add_action(
    'elementor/kit/register_tabs',
    function( $kit ) {
        $kit->register_tab( 'themee-style-kits', Themee_Style_Kits::class );
    }
);
